@@ -105,8 +105,9 @@ main(int argc, char **argv)
 		open_sock();
 	}
 
-	/* if we're running in foreground, we don't daemonize */
-	if (!foreground) {
+	/* if we're running in the background, and we're not being started */
+	/* by systemd */
+	if (!foreground  &&  !is_socket(STDIN_FILENO)) {
 		if (daemonize() < 0)
 			exit(EXIT_FAILURE);
 	}
@@ -393,7 +394,10 @@ std2null(void)
 	}
 
 	/* set up stdin, stdout, stderr to /dev/null */
-	if (dup2(nullfd, STDIN_FILENO) != STDIN_FILENO) {
+
+	/* don't redirect stdin if we're being sent a socket by systemd */
+	if (!is_socket(STDIN_FILENO)  && 
+			dup2(nullfd, STDIN_FILENO) != STDIN_FILENO) {
 		acpid_log(LOG_ERR, "dup2() stdin: %s", strerror(errno));
 		return -1;
 	}
