@@ -645,7 +645,7 @@ do_cmd_rule(struct rule *rule, const char *event)
 		execl("/bin/sh", "/bin/sh", "-c", action, NULL);
 		/* should not get here */
 		acpid_log(LOG_ERR, "execl(): %s", strerror(errno));
-		exit(EXIT_FAILURE);
+		_exit(EXIT_FAILURE);
 	}
 
 	/* parent */
